@@ -1,4 +1,4 @@
-.onLoad <- function(lib, pkg) {
+.onAttach <- function(lib, pkg) {
 	ver <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), "Version")
         packageStartupMessage(paste(pkg, ver))
 }
